@@ -154,26 +154,28 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
   ## First, find the interaction terms based on the given formula
   int_terms <- get_term_names(x$terms, vnames = colnames(training))
 
-  ## Check to see if any variables are non-numeric and issue a warning
-  ## if that is the case
-  vars <-
-    unique(unlist(lapply(make_new_formula(int_terms), all.vars)))
-  var_check <- info[info$variable %in% vars, ]
-  if (any(var_check$type == "nominal"))
-    warning(
-      "Categorical variables used in `step_interact` should probably be ",
-      "avoided;  This can lead to differences in dummy variable values that ",
-      "are produced by `step_dummy`. Please convert all involved variables ",
-      "to dummy variables first.", call. = FALSE
-    )
+  if (!all(is.na(int_terms))) {
+    ## Check to see if any variables are non-numeric and issue a warning
+    ## if that is the case
+    vars <-
+      unique(unlist(lapply(make_new_formula(int_terms), all.vars)))
+    var_check <- info[info$variable %in% vars, ]
+    if (any(var_check$type == "nominal"))
+      warning(
+        "Categorical variables used in `step_interact` should probably be ",
+        "avoided;  This can lead to differences in dummy variable values that ",
+        "are produced by `step_dummy`. Please convert all involved variables ",
+        "to dummy variables first.", call. = FALSE
+      )
 
-  ## For each interaction, create a new formula that has main effects
-  ## and only the interaction of choice (e.g. `a+b+c+a:b:c`)
-  int_forms <- make_new_formula(int_terms)
+    ## For each interaction, create a new formula that has main effects
+    ## and only the interaction of choice (e.g. `a+b+c+a:b:c`)
+    int_forms <- make_new_formula(int_terms)
 
-  ## Generate a standard R `terms` object from these short formulas and
-  ## save to make future interactions
-  int_terms <- make_small_terms(int_forms, training)
+    ## Generate a standard R `terms` object from these short formulas and
+    ## save to make future interactions
+    int_terms <- make_small_terms(int_forms, training)
+  }
 
   step_interact_new(
     terms = x$terms,
@@ -189,6 +191,11 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_interact <- function(object, new_data, ...) {
+
+  # When the interaction specification failed, just move on
+  if (isTRUE(all(is.na(object$object))))
+    return(new_data)
+
   ## `na.action` cannot be passed to `model.matrix` but we
   ## can change it globally for a bit
 
@@ -242,7 +249,7 @@ make_new_formula <- function(x) {
 ## term expansion (without `.`s). This returns the factor
 ## names and would not expand dummy variables.
 get_term_names <- function(form, vnames) {
-  if(!is_formula(form))
+  if (!is_formula(form))
     form <- as.formula(form)
 
   ## We are going to cheat and make a small fake data set to
@@ -251,7 +258,19 @@ get_term_names <- function(form, vnames) {
   ## pick off the interactions
   dat <- matrix(1, nrow = 5, ncol = length(vnames))
   colnames(dat) <- vnames
-  nms <- colnames(model.matrix(form, data = as.data.frame(dat)))
+  nms <- try(
+    colnames(model.matrix(form, data = as.data.frame(dat))),
+    silent = TRUE
+  )
+  if (inherits(nms, "try-error")) {
+    warning(
+      "Interaction specification failed for: ",
+      deparse(form),
+      ". No interactions will be created.",
+      call. = FALSE
+      )
+    return(rlang::na_chr)
+  }
   nms <- nms[nms != "(Intercept)"]
   nms <- grep(":", nms, value = TRUE)
   nms
@@ -277,8 +296,15 @@ print.step_interact <-
     invisible(x)
   }
 
-int_name <- function(x)
-  get_term_names(x, all.vars(x))
+int_name <- function(x) {
+  if (inherits(x, "terms")) {
+    res <- get_term_names(x, all.vars(x))
+  } else {
+    res <- rlang::na_chr
+  }
+  res
+}
+
 
 #' @importFrom rlang na_dbl
 #' @rdname step_interact
