@@ -49,30 +49,29 @@ step_logit <-
            role = NA,
            trained = FALSE,
            columns = NULL,
-           skip = FALSE) {
+           skip = FALSE,
+           id = rand_id("logit")) {
     add_step(recipe,
              step_logit_new(
                terms = ellipse_check(...),
                role = role,
                trained = trained,
                columns = columns,
-               skip = skip
+               skip = skip,
+               id = id
              ))
   }
 
 step_logit_new <-
-  function(terms = NULL,
-           role = NA,
-           trained = FALSE,
-           columns = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, columns, skip, id) {
     step(
       subclass = "logit",
       terms = terms,
       role = role,
       trained = trained,
       columns = columns,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
@@ -86,18 +85,19 @@ prep.step_logit <- function(x, training, info = NULL, ...) {
     role = x$role,
     trained = TRUE,
     columns = col_names,
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @importFrom tibble as_tibble
 #' @importFrom stats binomial
 #' @export
-bake.step_logit <- function(object, newdata, ...) {
+bake.step_logit <- function(object, new_data, ...) {
   for (i in seq_along(object$columns))
-    newdata[, object$columns[i]] <-
-      binomial()$linkfun(getElement(newdata, object$columns[i]))
-  as_tibble(newdata)
+    new_data[, object$columns[i]] <-
+      binomial()$linkfun(getElement(new_data, object$columns[i]))
+  as_tibble(new_data)
 }
 
 
@@ -110,6 +110,9 @@ print.step_logit <-
 
 #' @rdname step_logit
 #' @param x A `step_logit` object.
+#' @export
 tidy.step_logit <- function(x, ...) {
-  simple_terms(x, ...)
+  res <- simple_terms(x, ...)
+  res$id <- x$id
+  res
 }
