@@ -12,8 +12,8 @@
 #'  method, these are not currently used.
 #' @param role Not used by this step since no new variables are
 #'  created.
-#' @param threshold A single numeric value between 0 (inclusive) 
-#'  and 1 for pooling. Factor levels whose rate of occurrence in 
+#' @param threshold A single numeric value between 0 (inclusive)
+#'  and 1 for pooling. Factor levels whose rate of occurrence in
 #'  the training set are below `threshold` will be "othered".
 #' @param other A single character value for the "other" category.
 #' @param objects A list of objects that contain the information
@@ -32,7 +32,7 @@
 #'   proportion in the training set is less than `threshold`.
 #'
 #' If no pooling is done the data are unmodified (although character data may
-#'   be changed to factors based on the value of `stringsAsFactors` in
+#'   be changed to factors based on the value of `strings_as_factors` in
 #'   [prep.recipe()]). Otherwise, a factor is always returned with
 #'   different factor levels.
 #'
@@ -42,11 +42,11 @@
 #' If the retained categories include the value of `other`, an error is
 #'   thrown. If `other` is in the list of discarded levels, no error
 #'   occurs.
-#'   
-#' When data to be processed contains novel levels (i.e., not 
-#' contained in the training set), the other category is assigned.   
+#'
+#' When data to be processed contains novel levels (i.e., not
+#' contained in the training set), the other category is assigned.
 #' @seealso [step_factor2string()], [step_string2factor()],
-#'  [dummy_names()], [step_regex()], [step_count()], 
+#'  [dummy_names()], [step_regex()], [step_count()],
 #'  [step_ordinalscore()], [step_unorder()], [step_novel()]
 #' @examples
 #' data(okc)
@@ -68,7 +68,7 @@
 #' table(okc_te$diet, collapsed$diet, useNA = "always")
 #'
 #' tidy(rec, number = 1)
-#' 
+#'
 #' # novel levels are also "othered"
 #' tahiti <- okc[1,]
 #' tahiti$location <- "a magical place"
@@ -81,7 +81,8 @@ step_other <-
            threshold = .05,
            other = "other",
            objects = NULL,
-           skip = FALSE) {
+           skip = FALSE,
+           id = rand_id("other")) {
     if (threshold <= 0)
       stop("`threshold` should be greater than zero", call. = FALSE)
     if (threshold >= 1)
@@ -95,19 +96,14 @@ step_other <-
         threshold = threshold,
         other = other,
         objects = objects,
-        skip = skip
+        skip = skip,
+        id = id
       )
     )
   }
 
 step_other_new <-
-  function(terms = NULL,
-           role = NA,
-           trained = FALSE,
-           threshold = NULL,
-           other = NULL,
-           objects = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, threshold, other, objects, skip, id) {
     step(
       subclass = "other",
       terms = terms,
@@ -116,7 +112,8 @@ step_other_new <-
       threshold = threshold,
       other = other,
       objects = objects,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
@@ -135,37 +132,38 @@ prep.step_other <- function(x, training, info = NULL, ...) {
     threshold = x$threshold,
     other = x$other,
     objects = objects,
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @importFrom tibble as_tibble is_tibble
 #' @export
-bake.step_other <- function(object, newdata, ...) {
+bake.step_other <- function(object, new_data, ...) {
   for (i in names(object$objects)) {
     if (object$objects[[i]]$collapse) {
-      tmp <- if (!is.character(newdata[, i]))
-        as.character(getElement(newdata, i))
+      tmp <- if (!is.character(new_data[, i]))
+        as.character(getElement(new_data, i))
       else
-        getElement(newdata, i)
-      
+        getElement(new_data, i)
+
       tmp <- ifelse(
         !(tmp %in% object$objects[[i]]$keep) & !is.na(tmp),
         object$objects[[i]]$other,
         tmp
       )
-      
-      # assign other factor levels other here too. 
+
+      # assign other factor levels other here too.
       tmp <- factor(tmp,
                     levels = c(object$objects[[i]]$keep,
                                object$objects[[i]]$other))
-      
-      newdata[, i] <- tmp
+
+      new_data[, i] <- tmp
     }
   }
-  if (!is_tibble(newdata))
-    newdata <- as_tibble(newdata)
-  newdata
+  if (!is_tibble(new_data))
+    new_data <- as_tibble(new_data)
+  new_data
 }
 
 print.step_other <-
@@ -182,15 +180,15 @@ keep_levels <- function(x, prop = .1, other = "other") {
     sort(table(x, useNA = "no"), decreasing = TRUE) / sum(!is.na(x))
   dropped <- which(xtab < prop)
   orig <- levels(x)
-  
+
   if (length(dropped) > 0)
     keepers <- names(xtab[-dropped])
   else
     keepers <- orig
-  
+
   if (length(keepers) == 0)
     keepers <- names(xtab)[which.max(xtab)]
-  
+
   if (other %in% keepers)
     stop(
       "The level ",
@@ -198,7 +196,7 @@ keep_levels <- function(x, prop = .1, other = "other") {
       " is already a factor level that will be retained. ",
       "Please choose a different value.", call. = FALSE
     )
-  
+
   list(keep = orig[orig %in% keepers],
        collapse = TRUE, # not needed but kept for old versions
        other = other)
@@ -208,6 +206,7 @@ keep_levels <- function(x, prop = .1, other = "other") {
 #' @rdname step_other
 #' @param x A `step_other` object.
 #' @importFrom purrr map
+#' @export
 tidy.step_other <- function(x, ...) {
   if (is_trained(x)) {
     values <- purrr::map(x$objects, function(x) x$keep)
@@ -219,5 +218,6 @@ tidy.step_other <- function(x, ...) {
     res <- tibble(terms = term_names,
                   retained = rep(na_chr, length(term_names)))
   }
+  res$id <- x$id
   res
 }
