@@ -13,7 +13,7 @@
 #'  created.
 #' @param sds A named numeric vector of standard deviations This
 #'  is `NULL` until computed by [prep.recipe()].
-#' @param na.rm A logical value indicating whether `NA`
+#' @param na_rm A logical value indicating whether `NA`
 #'  values should be removed when computing the standard deviation.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
@@ -56,8 +56,9 @@ step_scale <-
            role = NA,
            trained = FALSE,
            sds = NULL,
-           na.rm = TRUE,
-           skip = FALSE) {
+           na_rm = TRUE,
+           skip = FALSE,
+           id = rand_id("scale")) {
     add_step(
       recipe,
       step_scale_new(
@@ -65,27 +66,24 @@ step_scale <-
         role = role,
         trained = trained,
         sds = sds,
-        na.rm = na.rm,
-        skip = skip
+        na_rm = na_rm,
+        skip = skip,
+        id = id
       )
     )
   }
 
 step_scale_new <-
-  function(terms = NULL,
-           role = NA,
-           trained = FALSE,
-           sds = NULL,
-           na.rm = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, sds, na_rm, skip, id) {
     step(
       subclass = "scale",
       terms = terms,
       role = role,
       trained = trained,
       sds = sds,
-      na.rm = na.rm,
-      skip = skip
+      na_rm = na_rm,
+      skip = skip,
+      id = id
     )
   }
 
@@ -96,25 +94,26 @@ prep.step_scale <- function(x, training, info = NULL, ...) {
   check_type(training[, col_names])
 
   sds <-
-    vapply(training[, col_names], sd, c(sd = 0), na.rm = x$na.rm)
+    vapply(training[, col_names], sd, c(sd = 0), na.rm = x$na_rm)
   step_scale_new(
     terms = x$terms,
     role = x$role,
     trained = TRUE,
     sds,
-    na.rm = x$na.rm,
-    skip = x$skip
+    na_rm = x$na_rm,
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_scale <- function(object, newdata, ...) {
+bake.step_scale <- function(object, new_data, ...) {
   res <-
-    sweep(as.matrix(newdata[, names(object$sds)]), 2, object$sds, "/")
+    sweep(as.matrix(new_data[, names(object$sds)]), 2, object$sds, "/")
   if (is.matrix(res) && ncol(res) == 1)
     res <- res[, 1]
-  newdata[, names(object$sds)] <- res
-  as_tibble(newdata)
+  new_data[, names(object$sds)] <- res
+  as_tibble(new_data)
 }
 
 print.step_scale <-
@@ -127,6 +126,7 @@ print.step_scale <-
 
 #' @rdname step_scale
 #' @param x A `step_scale` object.
+#' @export
 tidy.step_scale <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = names(x$sds),
@@ -136,5 +136,6 @@ tidy.step_scale <- function(x, ...) {
     res <- tibble(terms = term_names,
                   value = na_dbl)
   }
+  res$id <- x$id
   res
 }
