@@ -4,6 +4,8 @@
 #'  regarding a recipe or operation within the recipe (when a `tidy`
 #'  method for the operation exists).
 #'
+#' @name tidy.recipe
+#'
 #' @param x A `recipe` object (trained or otherwise).
 #' @param number An integer or `NA`. If missing, the return
 #'  value is a list of the operation in the recipe. If a number is
@@ -16,8 +18,8 @@
 #'  `operation` (either "step" or "check"),
 #'  `type` (the method, e.g. "nzv", "center"), a logical
 #'  column called `trained` for whether the operation has been
-#'  estimated using `prep`, and a logical for `skip`.
-#' @export
+#'  estimated using `prep`, a logical for `skip`, and a character column `id`. 
+#'
 #' @examples
 #' data(okc)
 #'
@@ -37,8 +39,10 @@
 #'
 #' tidy(okc_rec_trained)
 #' tidy(okc_rec_trained, number = 3)
+NULL
 
-#' @importFrom broom tidy
+#' @rdname tidy.recipe
+#' @export
 tidy.recipe <- function(x, number = NA, ...) {
   num_oper <- length(x$steps)
   if (num_oper == 0)
@@ -46,6 +50,7 @@ tidy.recipe <- function(x, number = NA, ...) {
   pattern <- "(^step_)|(^check_)"
   if (is.na(number)) {
     skipped <- vapply(x$steps, function(x) x$skip, logical(1))
+    ids <- vapply(x$steps, function(x) x$id, character(1))
 
     oper_classes <- lapply(x$steps, class)
     oper_classes <- grep("_", unlist(oper_classes), value = TRUE)
@@ -61,7 +66,8 @@ tidy.recipe <- function(x, number = NA, ...) {
                   operation = oper,
                   type = oper_types,
                   trained = is_trained,
-                  skip = skipped)
+                  skip = skipped,
+                  id = ids)
   } else {
     if (number > num_oper || length(number) > 1)
       stop("`number` should be a single value between 1 and ",
@@ -72,12 +78,15 @@ tidy.recipe <- function(x, number = NA, ...) {
   res
 }
 
+#' @rdname tidy.recipe
 #' @export
 tidy.step <- function(x, ...) {
   stop("No `tidy` method for a step with classes: ",
        paste0(class(x), collapse = ", "),
        call. = FALSE)
 }
+
+#' @rdname tidy.recipe
 #' @export
 tidy.check <- function(x, ...) {
   stop("No `tidy` method for a check with classes: ",
