@@ -1,6 +1,9 @@
 library(testthat)
 library(recipes)
 
+context("Dummy variable creation")
+
+
 data(okc)
 
 okc_missing <- okc
@@ -14,9 +17,9 @@ okc_fac$location <- factor(okc_fac$location)
 
 test_that('dummy variables with factor inputs', {
   rec <- recipe(age ~ location + diet, data = okc_fac)
-  dummy <- rec %>% step_dummy(diet, location)
-  dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE, stringsAsFactors = FALSE)
-  dummy_pred <- bake(dummy_trained, newdata = okc_fac, all_predictors())
+  dummy <- rec %>% step_dummy(diet, location, id = "")
+  dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE, strings_as_factors = FALSE)
+  dummy_pred <- bake(dummy_trained, new_data = okc_fac, all_predictors())
   dummy_pred <- dummy_pred[, order(colnames(dummy_pred))]
   dummy_pred <- as.data.frame(dummy_pred)
   rownames(dummy_pred) <- NULL
@@ -32,25 +35,53 @@ test_that('dummy variables with factor inputs', {
   expect_equivalent(dummy_pred, exp_res)
 
   dum_tibble <-
-    tibble(terms = c("diet", "location"))
-
+    tibble(terms = c("diet", "location"), columns = rep(rlang::na_chr, 2), id = "")
+  dum_tibble_prepped_1 <-
+    tibble(
+      terms = "diet",
+      columns = attributes(dummy_trained$steps[[1]]$levels$diet)$values,
+      id = ""
+    )
+  dum_tibble_prepped_2 <-
+    tibble(
+      terms = "location",
+      columns = attributes(dummy_trained$steps[[1]]$levels$location)$values,
+      id = ""
+    )
   expect_equal(tidy(dummy, 1), dum_tibble)
-  expect_equal(tidy(dummy_trained, 1), dum_tibble)
+  expect_equal(
+    tidy(dummy_trained, 1),
+    bind_rows(dum_tibble_prepped_1, dum_tibble_prepped_2)
+  )
 })
 
-test_that('dummy variables with string inputs', {
+test_that('dummy variables with non-factor inputs', {
   rec <- recipe(age ~ location + diet, data = okc)
   dummy <- rec %>% step_dummy(diet, location)
-  expect_error(
-    prep(dummy, training = okc, verbose = FALSE, stringsAsFactors = FALSE)
+
+  expect_warning(
+    expect_error(
+      prep(dummy, training = okc, verbose = FALSE, strings_as_factors = FALSE)
+    )
   )
+
+  okc_fac_ish <-
+    okc_fac %>%
+    mutate(diet = as.character(diet))
+
+  expect_warning(
+    recipe(age ~ location + height + diet, data = okc_fac_ish) %>%
+      step_dummy(diet, location, height) %>%
+      prep(training = okc_fac_ish, verbose = FALSE, strings_as_factors = FALSE)
+  )
+
 })
 
 test_that('create all dummy variables', {
   rec <- recipe(age ~ location + diet + height, data = okc_fac)
   dummy <- rec %>% step_dummy(diet, location, one_hot = TRUE)
-  dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE, stringsAsFactors = FALSE)
-  dummy_pred <- bake(dummy_trained, newdata = okc_fac, all_predictors())
+  dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE, strings_as_factors = FALSE)
+  dummy_pred <- bake(dummy_trained, new_data = okc_fac, all_predictors())
   dummy_pred <- dummy_pred[, order(colnames(dummy_pred))]
   dummy_pred <- as.data.frame(dummy_pred)
   rownames(dummy_pred) <- NULL
@@ -71,9 +102,9 @@ test_that('tests for issue #91', {
   rec <- recipe(~ diet, data = okc)
   factors <- rec %>% step_dummy(diet)
   factors <- prep(factors, training = okc)
-  factors_data_1 <- bake(factors, newdata = okc)
+  factors_data_1 <- bake(factors, new_data = okc)
   # Remove one category in diet
-  factors_data_2 <- bake(factors, newdata = okc %>% filter(diet != 'halal'))
+  factors_data_2 <- bake(factors, new_data = okc %>% filter(diet != 'halal'))
   expect_equal(names(factors_data_1), names(factors_data_2))
 
   # now with ordered factor
@@ -82,9 +113,9 @@ test_that('tests for issue #91', {
   rec <- recipe(~ ordered_diet, data = okc)
   orderedfac <- rec %>% step_dummy(ordered_diet)
   orderedfac <- prep(orderedfac, training = okc)
-  ordered_data_1 <- bake(orderedfac, newdata = okc)
+  ordered_data_1 <- bake(orderedfac, new_data = okc)
   # Remove one category in diet
-  ordered_data_2 <- bake(orderedfac, newdata = okc %>% filter(diet != 'halal'))
+  ordered_data_2 <- bake(orderedfac, new_data = okc %>% filter(diet != 'halal'))
   expect_equal(names(ordered_data_1), names(ordered_data_2))
 
 })
@@ -92,17 +123,21 @@ test_that('tests for issue #91', {
 test_that('tests for NA values in factor', {
   rec <- recipe(~ diet, data = okc_missing)
   factors <- rec %>% step_dummy(diet)
-  factors <- prep(factors, training = okc_missing, retain = TRUE)
-  
+  expect_warning(
+    factors <- prep(factors, training = okc_missing, retain = TRUE)
+  )
+
   factors_data_0 <- juice(factors)
-  factors_data_1 <- bake(factors, newdata = okc_missing)
-  
+  expect_warning(
+    factors_data_1 <- bake(factors, new_data = okc_missing)
+  )
+
   expect_true(
     all(complete.cases(factors_data_0) == complete.cases(okc_missing[, "diet"]))
   )
   expect_true(
     all(complete.cases(factors_data_1) == complete.cases(okc_missing[, "diet"]))
-  )  
+  )
 })
 
 test_that('tests for NA values in ordered factor', {
@@ -110,17 +145,21 @@ test_that('tests for NA values in ordered factor', {
   okc_ordered$diet <- as.ordered(okc_ordered$diet)
   rec <- recipe(~ diet, data = okc_ordered)
   factors <- rec %>% step_dummy(diet)
-  factors <- prep(factors, training = okc_ordered, retain = TRUE)
-  
+  expect_warning(
+    factors <- prep(factors, training = okc_ordered, retain = TRUE)
+  )
+
   factors_data_0 <- juice(factors)
-  factors_data_1 <- bake(factors, newdata = okc_ordered)
-  
+  expect_warning(
+    factors_data_1 <- bake(factors, new_data = okc_ordered)
+  )
+
   expect_true(
     all(complete.cases(factors_data_0) == complete.cases(okc_ordered[, "diet"]))
   )
   expect_true(
     all(complete.cases(factors_data_1) == complete.cases(okc_ordered[, "diet"]))
-  )  
+  )
 })
 
 
@@ -137,25 +176,46 @@ test_that('new levels', {
   training$x1 <- as.factor(training$x1)
   testing$y <- as.factor(testing$y)
   testing$x1 <- as.factor(testing$x1)
-  
+
   expect_warning(
     recipes:::warn_new_levels(testing$x1, levels(training$x1))
   )
   expect_silent(
     recipes:::warn_new_levels(training$x1, levels(training$x1))
-  ) 
-  
-  rec <- recipe(y ~ x1, data = training) %>% 
+  )
+
+  rec <- recipe(y ~ x1, data = training) %>%
     step_dummy(x1)
   expect_silent(
     rec <- prep(rec, training = training, retain = TRUE)
   )
   expect_warning(
-    bake(rec, newdata = testing)
+    bake(rec, new_data = testing)
   )
 })
 
+test_that('tests for issue #301', {
 
+  rec <- recipe(~ Species, data = iris)
+  dummies <- rec %>% step_dummy(Species)
+  dummies <- prep(dummies, training = iris)
+  expect_equal(NULL, attr(dummies$steps[[1]]$levels$Species, ".Environment"))
+
+  saved_recipe <- tempfile()
+  saveRDS(dummies, file = saved_recipe)
+  read_recipe <- readRDS(file = saved_recipe)
+  unlink(saved_recipe)
+  expect_equal(bake(dummies, new_data = iris), bake(read_recipe, new_data = iris))
+
+  saved_dummies <- dummies
+  saved_recipe <- tempfile()
+  save(saved_dummies, file = saved_recipe)
+  rm(saved_dummies)
+  load(file = saved_recipe)
+  unlink(saved_recipe)
+  expect_equal(bake(dummies, new_data = iris), bake(saved_dummies, new_data = iris))
+
+})
 
 
 
