@@ -1,6 +1,9 @@
 library(recipes)
 library(testthat)
 
+context("Indicator for novel levels")
+
+
 n <- 200
 
 set.seed(8575)
@@ -34,10 +37,10 @@ rec <- recipe(~ ., data = tr_dat)
 test_that('basic functionality', {
   ex_1 <- rec %>%
     step_novel(all_predictors()) %>%
-    prep(tr_dat, stringsAsFactors = FALSE, retain = TRUE) 
+    prep(tr_dat, strings_as_factors = FALSE, retain = TRUE) 
   
-  ex_1_tr <- bake(ex_1, newdata = tr_dat)
-  ex_1_te <- bake(ex_1, newdata = te_dat)
+  ex_1_tr <- bake(ex_1, new_data = tr_dat)
+  ex_1_te <- bake(ex_1, new_data = te_dat)
   
   all(ex_1_te$v[!(ex_1_te$v %in% letters[1:3])] == "new")
   
@@ -89,7 +92,7 @@ test_that('missing values', {
   ex_2 <- rec %>%
     step_novel(all_predictors()) %>%
     prep(training  = tr_dat)
-  ex_2_te <- bake(ex_2, newdata = te_miss)
+  ex_2_te <- bake(ex_2, new_data = te_miss)
   expect_equal(which(is.na(te_miss$y)), which(is.na(ex_2_te$y)))
   expect_equal(which(is.na(te_miss$z)), which(is.na(ex_2_te$z)))
 })
