@@ -2,6 +2,9 @@ library(testthat)
 library(recipes)
 data(biomass)
 
+context("PCA")
+
+
 biomass_tr <- biomass[biomass$dataset == "Training",]
 biomass_te <- biomass[biomass$dataset == "Testing",]
 
@@ -16,15 +19,15 @@ test_that('correct PCA values', {
     step_center(carbon, hydrogen, oxygen ,nitrogen, sulfur) %>%
     step_scale(carbon, hydrogen, oxygen ,nitrogen, sulfur) %>%
     step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur,
-             options = list(retx = TRUE))
+             options = list(retx = TRUE), id = "")
 
   pca_extract_trained <- prep(pca_extract, training = biomass_tr, verbose = FALSE)
 
-  pca_pred <- bake(pca_extract_trained, newdata = biomass_te, all_predictors())
+  pca_pred <- bake(pca_extract_trained, new_data = biomass_te, all_predictors())
   pca_pred <- as.matrix(pca_pred)
 
   pca_exp <- prcomp(biomass_tr[, 3:7], center = TRUE, scale. = TRUE, retx = TRUE)
-  pca_pred_exp <- predict(pca_exp, biomass_te[, 3:7])[, 1:pca_extract$steps[[3]]$num]
+  pca_pred_exp <- predict(pca_exp, biomass_te[, 3:7])[, 1:pca_extract$steps[[3]]$num_comp]
 
   rownames(pca_pred) <- NULL
   rownames(pca_pred_exp) <- NULL
@@ -34,7 +37,8 @@ test_that('correct PCA values', {
   tidy_exp_un <- tibble(
     terms = c("carbon", "hydrogen", "oxygen" ,"nitrogen", "sulfur"),
     value = rep(NA_real_, 5),
-    component = rep(NA_character_, 5)
+    component = rep(NA_character_, 5),
+    id = ""
   )
   expect_equal(tidy_exp_un, tidy(pca_extract, number = 3))
 
@@ -45,9 +49,10 @@ test_that('correct PCA values', {
   pca_obj <- utils::stack(pca_obj)
 
   tidy_exp_tr <- tibble(
-    terms = rep(tidy_exp_un$terms, pca_extract_trained$steps[[3]]$num),
+    terms = rep(tidy_exp_un$terms, pca_extract_trained$steps[[3]]$num_comp),
     value = pca_obj$values,
-    component = as.character(pca_obj$ind)
+    component = as.character(pca_obj$ind),
+    id = ""
   )
   expect_equal(
     as.data.frame(tidy_exp_tr),
@@ -65,7 +70,7 @@ test_that('correct PCA values with threshold', {
   pca_exp <- prcomp(biomass_tr[, 3:7], center = TRUE, scale. = TRUE, retx = TRUE)
   # cumsum(pca_exp$sdev^2)/sum(pca_exp$sdev^2)
 
-  expect_equal(pca_extract_trained$steps[[3]]$num, 2)
+  expect_equal(pca_extract_trained$steps[[3]]$num_comp, 2)
 })
 
 
@@ -73,11 +78,11 @@ test_that('Reduced rotation size', {
   pca_extract <- rec %>%
     step_center(carbon, hydrogen, oxygen ,nitrogen, sulfur) %>%
     step_scale(carbon, hydrogen, oxygen ,nitrogen, sulfur) %>%
-    step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur, num = 3)
+    step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur, num_comp = 3)
 
   pca_extract_trained <- prep(pca_extract, training = biomass_tr, verbose = FALSE)
 
-  pca_pred <- bake(pca_extract_trained, newdata = biomass_te, all_predictors())
+  pca_pred <- bake(pca_extract_trained, new_data = biomass_te, all_predictors())
   pca_pred <- as.matrix(pca_pred)
 
   pca_exp <- prcomp(biomass_tr[, 3:7], center = TRUE, scale. = TRUE, retx = TRUE)
@@ -90,6 +95,12 @@ test_that('Reduced rotation size', {
   expect_equal(pca_pred, pca_pred_exp)
 })
 
+test_that('deprecated arg', {
+  expect_message(
+    rec %>%
+      step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur, num = 2)
+  )
+})
 
 test_that('printing', {
   pca_extract <- rec %>%
